@@ -1,6 +1,6 @@
 package App::Info::Lib::Iconv;
 
-# $Id: Iconv.pm,v 1.22 2002/06/30 22:18:41 david Exp $
+# $Id: Iconv.pm,v 1.23 2002/08/08 19:19:18 david Exp $
 
 =head1 NAME
 
@@ -44,7 +44,7 @@ use App::Info::Util;
 use App::Info::Lib;
 use vars qw(@ISA $VERSION);
 @ISA = qw(App::Info::Lib);
-$VERSION = '0.21';
+$VERSION = '0.22';
 
 my $u = App::Info::Util->new;
 
@@ -743,7 +743,8 @@ Improve this class by borrowing code from Matt Seargent's AxKit F<Makefil.PL>.
 
 =head1 BUGS
 
-Feel free to drop me a line if you discover any bugs. Patches welcome.
+Report all bugs via the CPAN Request Tracker at
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Info>.
 
 =head1 AUTHOR
 
